//=======================================================================
// DingMee Translator
// URLs: http://chrm.info/cms/dingmee-translator
// Copyright (C) 2012, Christoph Maciejewski
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//=======================================================================

import QtQuick 1.1
import com.nokia.meego 1.0
import "background.js" as MyScript
import SettingsManager 1.0

PageStackWindow {
    id: appWindow

    initialPage: mainPage

    MainPage {
        id: mainPage        
    }

    SettingsManager {
        id: settingsmanager
    }

    About {
        id: aboutPage
    }

    Settings {
        id: settingsPage
    }

    Component.onCompleted: {
        if(!settingsmanager.isDictAvailable()) {
            pageStack.push(settingsPage);
            backButton.enabled = true;
            backButton.opacity = 1.0;
        } else {
            backButton.enabled = false;
            backButton.opacity = 0.6
        }        
    }

    ToolBarLayout {
        id: commonTools
        visible: true

        ToolIcon {
            id: backButton
            platformIconId: "toolbar-back";
            anchors.left: (parent === undefined) ? undefined : parent.left
            enabled: false
            onClicked: {
                myMenu.close();
                pageStack.pop();

                menuSettings.enabled = true;
                menuAbout.enabled = true;

                if(mainPage.visible) {
                    backButton.enabled = false;
                    backButton.opacity = 0.6
                }

                mainPage.updateLangList();
            }
        }

        ToolIcon {
            id: menuButton
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: (myMenu.status === DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }

    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                id: menuSettings
                text: qsTr("Settings")
                onClicked: {
                    myMenu.close();
                    //pageStack.push(Qt.resolvedUrl("Settings.qml"))
                    // Use persistent Pages
                    //pageStack.push(MyScript.getSettingsPage());
                    pageStack.push(settingsPage);
                    menuSettings.enabled = false;
                    backButton.enabled = true;
                    backButton.opacity = 1.0;
                    mainPage.clearLangList();
                }
                //backButton.enabled: true;
            }
            MenuItem {
                id: menuAbout
                text: qsTr("About")
                onClicked: {
                    myMenu.close();
                    //pageStack.push(Qt.resolvedUrl("About.qml"))
                    // Use persistent Pages
                    //pageStack.push(MyScript.getAboutPage());
                    pageStack.push(aboutPage);
                    menuAbout.enabled = false;
                    backButton.enabled = true;
                    backButton.opacity = 1.0;
                    mainPage.clearLangList();
                }
                //backButton.enabled: true;
            }            
        }
    }
}
